aboutsummaryrefslogtreecommitdiff
path: root/src/dynamics/joint/prismatic_joint.rs
diff options
context:
space:
mode:
authorSébastien Crozet <developer@crozet.re>2021-01-29 14:42:32 +0100
committerGitHub <noreply@github.com>2021-01-29 14:42:32 +0100
commit7ca46f38cde6cf8bf8bf41ea6067ae5bc938205c (patch)
tree3781b9d7c92a6a8111573ba4cae1c5d41435950e /src/dynamics/joint/prismatic_joint.rs
parente6fc8f67faf3e37afe38d683cbd930d457f289be (diff)
parent825f33efaec4ce6a8903751e836a0ea9c466ff92 (diff)
downloadrapier-7ca46f38cde6cf8bf8bf41ea6067ae5bc938205c.tar.gz
rapier-7ca46f38cde6cf8bf8bf41ea6067ae5bc938205c.tar.bz2
rapier-7ca46f38cde6cf8bf8bf41ea6067ae5bc938205c.zip
Merge pull request #79 from dimforge/split_geom
Move most of the geometric code to another crate.
Diffstat (limited to 'src/dynamics/joint/prismatic_joint.rs')
-rw-r--r--src/dynamics/joint/prismatic_joint.rs68
1 files changed, 34 insertions, 34 deletions
diff --git a/src/dynamics/joint/prismatic_joint.rs b/src/dynamics/joint/prismatic_joint.rs
index a6fd558..174ce79 100644
--- a/src/dynamics/joint/prismatic_joint.rs
+++ b/src/dynamics/joint/prismatic_joint.rs
@@ -1,4 +1,4 @@
-use crate::math::{Isometry, Point, Vector, DIM};
+use crate::math::{Isometry, Point, Real, Vector, DIM};
use crate::utils::WBasis;
use na::Unit;
#[cfg(feature = "dim2")]
@@ -11,35 +11,35 @@ use na::Vector5;
/// A joint that removes all relative motion between two bodies, except for the translations along one axis.
pub struct PrismaticJoint {
/// Where the prismatic joint is attached on the first body, expressed in the local space of the first attached body.
- pub local_anchor1: Point<f32>,
+ pub local_anchor1: Point<Real>,
/// Where the prismatic joint is attached on the second body, expressed in the local space of the second attached body.
- pub local_anchor2: Point<f32>,
- pub(crate) local_axis1: Unit<Vector<f32>>,
- pub(crate) local_axis2: Unit<Vector<f32>>,
- pub(crate) basis1: [Vector<f32>; DIM - 1],
- pub(crate) basis2: [Vector<f32>; DIM - 1],
+ pub local_anchor2: Point<Real>,
+ pub(crate) local_axis1: Unit<Vector<Real>>,
+ pub(crate) local_axis2: Unit<Vector<Real>>,
+ pub(crate) basis1: [Vector<Real>; DIM - 1],
+ pub(crate) basis2: [Vector<Real>; DIM - 1],
/// The impulse applied by this joint on the first body.
///
/// The impulse applied to the second body is given by `-impulse`.
#[cfg(feature = "dim3")]
- pub impulse: Vector5<f32>,
+ pub impulse: Vector5<Real>,
/// The impulse applied by this joint on the first body.
///
/// The impulse applied to the second body is given by `-impulse`.
#[cfg(feature = "dim2")]
- pub impulse: Vector2<f32>,
+ pub impulse: Vector2<Real>,
/// Whether or not this joint should enforce translational limits along its axis.
pub limits_enabled: bool,
/// The min an max relative position of the attached bodies along this joint's axis.
- pub limits: [f32; 2],
+ pub limits: [Real; 2],
/// The impulse applied by this joint on the first body to enforce the position limit along this joint's axis.
///
/// The impulse applied to the second body is given by `-impulse`.
- pub limits_impulse: f32,
+ pub limits_impulse: Real,
// pub motor_enabled: bool,
// pub target_motor_vel: f32,
// pub max_motor_impulse: f32,
// pub motor_impulse: f32,
}
impl PrismaticJoint {
@@ -47,10 +47,10 @@ impl PrismaticJoint {
/// in the local-space of the affected bodies.
#[cfg(feature = "dim2")]
pub fn new(
- local_anchor1: Point<f32>,
- local_axis1: Unit<Vector<f32>>,
- local_anchor2: Point<f32>,
- local_axis2: Unit<Vector<f32>>,
+ local_anchor1: Point<Real>,
+ local_axis1: Unit<Vector<Real>>,
+ local_anchor2: Point<Real>,
+ local_axis2: Unit<Vector<Real>>,
) -> Self {
Self {
local_anchor1,
@@ -61,11 +61,11 @@ impl PrismaticJoint {
basis2: local_axis2.orthonormal_basis(),
impulse: na::zero(),
limits_enabled: false,
- limits: [-f32::MAX, f32::MAX],
+ limits: [-Real::MAX, Real::MAX],
limits_impulse: 0.0,
// motor_enabled: false,
// target_motor_vel: 0.0,
- // max_motor_impulse: f32::MAX,
+ // max_motor_impulse: Real::MAX,
// motor_impulse: 0.0,
}
}
@@ -78,12 +78,12 @@ impl PrismaticJoint {
/// computed arbitrarily.
#[cfg(feature = "dim3")]
pub fn new(
- local_anchor1: Point<f32>,
- local_axis1: Unit<Vector<f32>>,
- local_tangent1: Vector<f32>,
- local_anchor2: Point<f32>,
- local_axis2: Unit<Vector<f32>>,
- local_tangent2: Vector<f32>,
+ local_anchor1: Point<Real>,
+ local_axis1: Unit<Vector<Real>>,
+ local_tangent1: Vector<Real>,
+ local_anchor2: Point<Real>,
+ local_axis2: Unit<Vector<Real>>,
+ local_tangent2: Vector<Real>,
) -> Self {
let basis1 = if let Some(local_bitangent1) =
Unit::try_new(local_axis1.cross(&local_tangent1), 1.0e-3)
@@ -116,28 +116,28 @@ impl PrismaticJoint {
basis2,
impulse: na::zero(),
limits_enabled: false,
- limits: [-f32::MAX, f32::MAX],
+ limits: [-Real::MAX, Real::MAX],
limits_impulse: 0.0,
// motor_enabled: false,
// target_motor_vel: 0.0,
- // max_motor_impulse: f32::MAX,
+ // max_motor_impulse: Real::MAX,
// motor_impulse: 0.0,
}
}
/// The local axis of this joint, expressed in the local-space of the first attached body.
- pub fn local_axis1(&self) -> Unit<Vector<f32>> {
+ pub fn local_axis1(&self) -> Unit<Vector<Real>> {
self.local_axis1
}
/// The local axis of this joint, expressed in the local-space of the second attached body.
- pub fn local_axis2(&self) -> Unit<Vector<f32>> {
+ pub fn local_axis2(&self) -> Unit<Vector<Real>> {
self.local_axis2
}
// FIXME: precompute this?
#[cfg(feature = "dim2")]
- pub(crate) fn local_frame1(&self) -> Isometry<f32> {
+ pub(crate) fn local_frame1(&self) -> Isometry<Real> {
use na::{Matrix2, Rotation2, UnitComplex};
let mat = Matrix2::from_columns(&[self.local_axis1.into_inner(), self.basis1[0]]);
@@ -149,7 +149,7 @@ impl PrismaticJoint {
// FIXME: precompute this?
#[cfg(feature = "dim2")]
- pub(crate) fn local_frame2(&self) -> Isometry<f32> {
+ pub(crate) fn local_frame2(&self) -> Isometry<Real> {
use na::{Matrix2, Rotation2, UnitComplex};
let mat = Matrix2::from_columns(&[self.local_axis2.into_inner(), self.basis2[0]]);
@@ -161,7 +161,7 @@ impl PrismaticJoint {
// FIXME: precompute this?
#[cfg(feature = "dim3")]
- pub(crate) fn local_frame1(&self) -> Isometry<f32> {
+ pub(crate) fn local_frame1(&self) -> Isometry<Real> {
use na::{Matrix3, Rotation3, UnitQuaternion};
let mat = Matrix3::from_columns(&[
@@ -177,7 +177,7 @@ impl PrismaticJoint {
// FIXME: precompute this?
#[cfg(feature = "dim3")]
- pub(crate) fn local_frame2(&self) -> Isometry<f32> {
+ pub(crate) fn local_frame2(&self) -> Isometry<Real> {
use na::{Matrix3, Rotation3, UnitQuaternion};
let mat = Matrix3::from_columns(&[
@@ -11,35 +11,35 @@ use na::Vector5;
// pub motor_enabled: bool,
- // pub target_motor_vel: f32,
- // pub max_motor_impulse: f32,
- // pub motor_impulse: f32,
+ // pub target_motor_vel: Real,
+ // pub max_motor_impulse: Real,
+ // pub motor_impulse: Real,
}
impl PrismaticJoint {